compile_ast_with_engine

Function compile_ast_with_engine 

pub fn compile_ast_with_engine(
    ast: &PolydatFile,
    source: &str,
    options: &CompileOptions,
    log: Option<&mut CompileEventLog>,
    engine: Engine,
) -> Result<Box<dyn Kernel>, KernelError>
compile_polydat_with_engine from a parsed file: the parent compiles on engine through the assembler, and each for body compiles once for the interpreter as the traversal’s record and on any engine at activation (engine parity, step 8).