dispatch

Function dispatch 

pub fn dispatch(
    source_name: &str,
    constructor: &Expr,
) -> Result<Option<CursorSugar>, String>
Walk the inventory and dispatch to the first handler that matches constructor. Returns the rewrite to apply, None if no handler matches, or the handler’s error.