pub fn render_template(pieces: &[TilePiece], opts: &TileOptions) -> StringExpand description
Render pieces back to template text under opts, the inverse of
parse_template up to whitespace inside directives.
pub fn render_template(pieces: &[TilePiece], opts: &TileOptions) -> StringRender pieces back to template text under opts, the inverse of
parse_template up to whitespace inside directives.