TupleStream

Trait TupleStream 

pub trait TupleStream {
    // Required method
    fn advance(&mut self) -> Option<Tuple>;
}
A lazy tuple stream — advance returns the next tuple or None when the stream is exhausted.

Required Methods

fn advance(&mut self) -> Option<Tuple>

The next tuple, or None once the stream is exhausted.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors