pub trait KernelScope {
type Scoped;
// Required method
fn scope(&self, coords: &Tuple) -> Self::Scoped;
}Expand description
A parent value that can be scoped to a coordinate tuple,
producing an instance of Self::Scoped. Spec 9.5.3 names
this the “one-shot scope function.”
For polydat kernels this is
PolydatKernel::for_iteration(&canonical, &parent, &bindings).
For tests it can be any type that derives a scoped value
from a tuple.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".