pub enum SourceValueForm {
Opaque,
Ordinal,
}Expand description
A compact description of values which can be generated without rendering an opaque source item first.
Variants
Opaque
The source may be replayable, but the item must still be rendered.
Ordinal
The yielded scalar value is the ordinal itself. A typed consumer may apply its declared narrowing or wrapping conversion while vectorizing.