pub fn program_identity(kernel: &PolydatKernel) -> *const PolydatProgramExpand description
Identity of the program an activation runs over, for callers that want to assert the one-program-per-position property.
pub fn program_identity(kernel: &PolydatKernel) -> *const PolydatProgramIdentity of the program an activation runs over, for callers that want to assert the one-program-per-position property.