pub struct OutputAccessor { /* private fields */ }Expand description
Memoized output accessor for a named subset of outputs.
Created once from output names via PolydatState::accessor().
Subsequent pulls use pre-resolved indices — no name lookups.
Implementations
Sourceimpl OutputAccessor
impl OutputAccessor
Sourcepub fn pull_all<'a>(
&self,
state: &'a mut PolydatState,
program: &PolydatProgram,
) -> Vec<&'a Value>
pub fn pull_all<'a>( &self, state: &'a mut PolydatState, program: &PolydatProgram, ) -> Vec<&'a Value>
Pull all outputs in this accessor from the given state.