pub fn assert_value_node(
typ: PortType,
constraint: ConstConstraint,
) -> Box<dyn PolydatNode>Expand description
Construct a value assertion node for the given (type, constraint) pair.
pub fn assert_value_node(
typ: PortType,
constraint: ConstConstraint,
) -> Box<dyn PolydatNode>Construct a value assertion node for the given (type, constraint) pair.