pub fn same_constraint(a: &ConstConstraint, b: &ConstConstraint) -> boolExpand description
Whether two constraints state the same condition. A parser constraint equals another only when both name the same function.
pub fn same_constraint(a: &ConstConstraint, b: &ConstConstraint) -> boolWhether two constraints state the same condition. A parser constraint equals another only when both name the same function.