reg_view

Function reg_view 

pub fn reg_view(to: PortType) -> Option<Box<dyn PolydatNode>>
The view of a register word as to, the retag the assembler inserts between register ports of different lane typings. None when to is not a register type.