fbm_1d

Function fbm_1d 

pub fn fbm_1d(
    perm: &PermTable,
    base_x: f64,
    frequency: f64,
    octaves: u32,
) -> f64
1D fractal Brownian motion: octaves layers of Perlin noise, each at twice the frequency and half the amplitude of the last.