pub enum ScopeJoinError {
Cycle,
}Expand description
Why ResourceScope::join left a scope joined to nothing.
Variants
Cycle
Another thread joined scopes at the same moment in a way that, with this join, would have made a scope delegate to itself. This join is severed and the scope delegates to nothing.