verify_binders

Function verify_binders 

pub fn verify_binders(
    binders: &[Binder],
    wire_type: impl Fn(&str) -> Option<PortType>,
) -> Vec<BinderViolation>
Every slot whose wire type cannot satisfy its lvalue type, given a lookup from wire name to the program’s type for it.