pub fn auto_adapter(
from: PortType,
to: PortType,
) -> Option<Box<dyn PolydatNode>>Expand description
The lossless adapter node from one port type to another, if the catalog has one: what the assembler inserts between a wire and a port of different types.