pub fn element_kind(c: &Comprehension, name: &str) -> Option<ValueKind>Expand description
The kind of every value name takes in c: the kind its clause’s
source declares, the same in every branch of a union, or None when
a source’s values are of unknown or mixed kind or c does not bind
name.