pub fn reg_view(to: PortType) -> Option<Box<dyn PolydatNode>>Expand description
The view of a register word as to, the retag the assembler
inserts between register ports of different lane typings. None
when to is not a register type.
pub fn reg_view(to: PortType) -> Option<Box<dyn PolydatNode>>The view of a register word as to, the retag the assembler
inserts between register ports of different lane typings. None
when to is not a register type.